## Data extractor for PDF invoices 

To run the code:

1. Install the package using using the command:  
   `pip install invoiceocr-Gubs`
2. In your script, write:
    `from InvoiceOcrGubs import script`
3. To run the script, run command:
   `python <file_name> --pdf <pdf_name>`
2. A window will open up, select the desired rectangle by dragging with help of   mouse and then press c on keyboard
3. The window will close and the etxt will be showed on the terminal.
